Polynomial Package
==================

.. versionadded:: 1.4.0

.. currentmodule:: numpy.polynomial

.. toctree::
   :maxdepth: 2

   routines.polynomials.classes
   routines.polynomials.polynomial
   routines.polynomials.chebyshev
   routines.polynomials.legendre
   routines.polynomials.laguerre
   routines.polynomials.hermite
   routines.polynomials.hermite_e
